@@ -4,9 +4,9 @@ use solana_program::program_error::ProgramError;
 use solana_program::pubkey::PUBKEY_BYTES;
 use solana_program::{msg, pubkey::Pubkey};
 
-use crate::math::Decimal;
 use crate::solana_program::program_pack::{IsInitialized, Pack, Sealed};
 use crate::state::{PROGRAM_VERSION, UNINITIALIZED_VERSION};
+use solana_maths::Decimal;
 
 #[derive(Clone, Debug, Default, PartialEq)]
 pub struct StakingPool {
